# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: qm/pb/job_manager.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from qm.pb import errors_pb2 as qm_dot_pb_dot_errors__pb2
from qm.pb import general_messages_pb2 as qm_dot_pb_dot_general__messages__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='qm/pb/job_manager.proto',
  package='qm.grpc.jobManager',
  syntax='proto3',
  serialized_options=b'\n\022qm.grpc.jobManagerB\026JobManagerServiceProtoP\001\242\002\003HLW',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x17qm/pb/job_manager.proto\x12\x12qm.grpc.jobManager\x1a\x12qm/pb/errors.proto\x1a\x1cqm/pb/general_messages.proto\"r\n\x1bGetElementCorrectionRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x0e\n\x06qeName\x18\x02 \x01(\t\x12\x34\n\ncorrection\x18\x03 \x01(\x0b\x32 .qm.grpc.general_messages.Matrix\"\xa4\x01\n\x1cGetElementCorrectionResponse\x12N\n\x18jobManagerResponseHeader\x18\x01 \x01(\x0b\x32,.qm.grpc.jobManager.JobManagerResponseHeader\x12\x34\n\ncorrection\x18\x03 \x01(\x0b\x32 .qm.grpc.general_messages.Matrix\"r\n\x1bSetElementCorrectionRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12\x0e\n\x06qeName\x18\x02 \x01(\t\x12\x34\n\ncorrection\x18\x03 \x01(\x0b\x32 .qm.grpc.general_messages.Matrix\"\xa4\x01\n\x1cSetElementCorrectionResponse\x12N\n\x18jobManagerResponseHeader\x18\x01 \x01(\x0b\x32,.qm.grpc.jobManager.JobManagerResponseHeader\x12\x34\n\ncorrection\x18\x02 \x01(\x0b\x32 .qm.grpc.general_messages.Matrix\"\xac\x01\n\x18JobManagerResponseHeader\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05jobId\x18\x02 \x01(\t\x12\x32\n\x13jobManagerErrorType\x18\n \x01(\x0e\x32\x15.JobManagerErrorTypes\x12<\n\x0fjobErrorDetails\x18\x0b \x01(\x0b\x32#.qm.grpc.jobManager.JobErrorDetails\"\xb1\x01\n\x0fJobErrorDetails\x12H\n\x1djobOperationSpecificErrorType\x18\x01 \x01(\x0e\x32\x1f.JobOperationSpecificErrorTypesH\x00\x12\x36\n\x14\x63onfigQueryErrorType\x18\x02 \x01(\x0e\x32\x16.ConfigQueryErrorTypesH\x00\x12\x0f\n\x07message\x18\n \x01(\tB\x0b\n\terrorType\"[\n\x19JobOperationSpecificError\x12-\n\x04type\x18\x01 \x01(\x0e\x32\x1f.JobOperationSpecificErrorTypes\x12\x0f\n\x07message\x18\x02 \x01(\t\">\n\x10\x44igitalInputPort\x12\x16\n\x0e\x63ontrollerName\x18\x01 \x01(\t\x12\x12\n\nportNumber\x18\x02 \x01(\r\"o\n\x1eGetDigitalInputPolarityRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12>\n\x10\x64igitalInputPort\x18\x02 \x01(\x0b\x32$.qm.grpc.jobManager.DigitalInputPort\"\xf1\x01\n\x1fGetDigitalInputPolarityResponse\x12N\n\x18jobManagerResponseHeader\x18\x01 \x01(\x0b\x32,.qm.grpc.jobManager.JobManagerResponseHeader\x12>\n\x10\x64igitalInputPort\x18\x02 \x01(\x0b\x32$.qm.grpc.jobManager.DigitalInputPort\x12>\n\x08polarity\x18\x03 \x01(\x0e\x32,.qm.grpc.jobManager.DigitalInputPortPolarity\"\xaf\x01\n\x1eSetDigitalInputPolarityRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12>\n\x10\x64igitalInputPort\x18\x02 \x01(\x0b\x32$.qm.grpc.jobManager.DigitalInputPort\x12>\n\x08polarity\x18\x03 \x01(\x0e\x32,.qm.grpc.jobManager.DigitalInputPortPolarity\"\xb1\x01\n\x1fSetDigitalInputPolarityResponse\x12N\n\x18jobManagerResponseHeader\x18\x01 \x01(\x0b\x32,.qm.grpc.jobManager.JobManagerResponseHeader\x12>\n\x08polarity\x18\x02 \x01(\x0e\x32,.qm.grpc.jobManager.DigitalInputPortPolarity\"m\n\x1cGetDigitalInputWindowRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12>\n\x10\x64igitalInputPort\x18\x02 \x01(\x0b\x32$.qm.grpc.jobManager.DigitalInputPort\"\xbf\x01\n\x1dGetDigitalInputWindowResponse\x12N\n\x18jobManagerResponseHeader\x18\x01 \x01(\x0b\x32,.qm.grpc.jobManager.JobManagerResponseHeader\x12>\n\x10\x64igitalInputPort\x18\x02 \x01(\x0b\x32$.qm.grpc.jobManager.DigitalInputPort\x12\x0e\n\x06window\x18\x03 \x01(\r\"}\n\x1cSetDigitalInputWindowRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12>\n\x10\x64igitalInputPort\x18\x02 \x01(\x0b\x32$.qm.grpc.jobManager.DigitalInputPort\x12\x0e\n\x06window\x18\x03 \x01(\r\"\x7f\n\x1dSetDigitalInputWindowResponse\x12N\n\x18jobManagerResponseHeader\x18\x01 \x01(\x0b\x32,.qm.grpc.jobManager.JobManagerResponseHeader\x12\x0e\n\x06window\x18\x02 \x01(\r\"p\n\x1fGetDigitalInputThresholdRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12>\n\x10\x64igitalInputPort\x18\x02 \x01(\x0b\x32$.qm.grpc.jobManager.DigitalInputPort\"\xc5\x01\n GetDigitalInputThresholdResponse\x12N\n\x18jobManagerResponseHeader\x18\x01 \x01(\x0b\x32,.qm.grpc.jobManager.JobManagerResponseHeader\x12>\n\x10\x64igitalInputPort\x18\x02 \x01(\x0b\x32$.qm.grpc.jobManager.DigitalInputPort\x12\x11\n\tthreshold\x18\x03 \x01(\x01\"\x83\x01\n\x1fSetDigitalInputThresholdRequest\x12\r\n\x05jobId\x18\x01 \x01(\t\x12>\n\x10\x64igitalInputPort\x18\x02 \x01(\x0b\x32$.qm.grpc.jobManager.DigitalInputPort\x12\x11\n\tthreshold\x18\x03 \x01(\x01\"\x85\x01\n SetDigitalInputThresholdResponse\x12N\n\x18jobManagerResponseHeader\x18\x01 \x01(\x0b\x32,.qm.grpc.jobManager.JobManagerResponseHeader\x12\x11\n\tthreshold\x18\x02 \x01(\x01*;\n\x18\x44igitalInputPortPolarity\x12\x0f\n\x0b\x41\x43TIVE_HIGH\x10\x00\x12\x0e\n\nACTIVE_LOW\x10\x01\x32\xaf\x08\n\x11JobManagerService\x12{\n\x14GetElementCorrection\x12/.qm.grpc.jobManager.GetElementCorrectionRequest\x1a\x30.qm.grpc.jobManager.GetElementCorrectionResponse\"\x00\x12{\n\x14SetElementCorrection\x12/.qm.grpc.jobManager.SetElementCorrectionRequest\x1a\x30.qm.grpc.jobManager.SetElementCorrectionResponse\"\x00\x12\x84\x01\n\x17GetDigitalInputPolarity\x12\x32.qm.grpc.jobManager.GetDigitalInputPolarityRequest\x1a\x33.qm.grpc.jobManager.GetDigitalInputPolarityResponse\"\x00\x12\x84\x01\n\x17SetDigitalInputPolarity\x12\x32.qm.grpc.jobManager.SetDigitalInputPolarityRequest\x1a\x33.qm.grpc.jobManager.SetDigitalInputPolarityResponse\"\x00\x12~\n\x15GetDigitalInputWindow\x12\x30.qm.grpc.jobManager.GetDigitalInputWindowRequest\x1a\x31.qm.grpc.jobManager.GetDigitalInputWindowResponse\"\x00\x12~\n\x15SetDigitalInputWindow\x12\x30.qm.grpc.jobManager.SetDigitalInputWindowRequest\x1a\x31.qm.grpc.jobManager.SetDigitalInputWindowResponse\"\x00\x12\x87\x01\n\x18GetDigitalInputThreshold\x12\x33.qm.grpc.jobManager.GetDigitalInputThresholdRequest\x1a\x34.qm.grpc.jobManager.GetDigitalInputThresholdResponse\"\x00\x12\x87\x01\n\x18SetDigitalInputThreshold\x12\x33.qm.grpc.jobManager.SetDigitalInputThresholdRequest\x1a\x34.qm.grpc.jobManager.SetDigitalInputThresholdResponse\"\x00\x42\x34\n\x12qm.grpc.jobManagerB\x16JobManagerServiceProtoP\x01\xa2\x02\x03HLWb\x06proto3'
  ,
  dependencies=[qm_dot_pb_dot_errors__pb2.DESCRIPTOR,qm_dot_pb_dot_general__messages__pb2.DESCRIPTOR,])

_DIGITALINPUTPORTPOLARITY = _descriptor.EnumDescriptor(
  name='DigitalInputPortPolarity',
  full_name='qm.grpc.jobManager.DigitalInputPortPolarity',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ACTIVE_HIGH', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ACTIVE_LOW', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3035,
  serialized_end=3094,
)
_sym_db.RegisterEnumDescriptor(_DIGITALINPUTPORTPOLARITY)

DigitalInputPortPolarity = enum_type_wrapper.EnumTypeWrapper(_DIGITALINPUTPORTPOLARITY)
ACTIVE_HIGH = 0
ACTIVE_LOW = 1



_GETELEMENTCORRECTIONREQUEST = _descriptor.Descriptor(
  name='GetElementCorrectionRequest',
  full_name='qm.grpc.jobManager.GetElementCorrectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.jobManager.GetElementCorrectionRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qeName', full_name='qm.grpc.jobManager.GetElementCorrectionRequest.qeName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='correction', full_name='qm.grpc.jobManager.GetElementCorrectionRequest.correction', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=97,
  serialized_end=211,
)


_GETELEMENTCORRECTIONRESPONSE = _descriptor.Descriptor(
  name='GetElementCorrectionResponse',
  full_name='qm.grpc.jobManager.GetElementCorrectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobManagerResponseHeader', full_name='qm.grpc.jobManager.GetElementCorrectionResponse.jobManagerResponseHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='correction', full_name='qm.grpc.jobManager.GetElementCorrectionResponse.correction', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=214,
  serialized_end=378,
)


_SETELEMENTCORRECTIONREQUEST = _descriptor.Descriptor(
  name='SetElementCorrectionRequest',
  full_name='qm.grpc.jobManager.SetElementCorrectionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.jobManager.SetElementCorrectionRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='qeName', full_name='qm.grpc.jobManager.SetElementCorrectionRequest.qeName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='correction', full_name='qm.grpc.jobManager.SetElementCorrectionRequest.correction', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=380,
  serialized_end=494,
)


_SETELEMENTCORRECTIONRESPONSE = _descriptor.Descriptor(
  name='SetElementCorrectionResponse',
  full_name='qm.grpc.jobManager.SetElementCorrectionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobManagerResponseHeader', full_name='qm.grpc.jobManager.SetElementCorrectionResponse.jobManagerResponseHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='correction', full_name='qm.grpc.jobManager.SetElementCorrectionResponse.correction', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=661,
)


_JOBMANAGERRESPONSEHEADER = _descriptor.Descriptor(
  name='JobManagerResponseHeader',
  full_name='qm.grpc.jobManager.JobManagerResponseHeader',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='success', full_name='qm.grpc.jobManager.JobManagerResponseHeader.success', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.jobManager.JobManagerResponseHeader.jobId', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobManagerErrorType', full_name='qm.grpc.jobManager.JobManagerResponseHeader.jobManagerErrorType', index=2,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='jobErrorDetails', full_name='qm.grpc.jobManager.JobManagerResponseHeader.jobErrorDetails', index=3,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=664,
  serialized_end=836,
)


_JOBERRORDETAILS = _descriptor.Descriptor(
  name='JobErrorDetails',
  full_name='qm.grpc.jobManager.JobErrorDetails',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobOperationSpecificErrorType', full_name='qm.grpc.jobManager.JobErrorDetails.jobOperationSpecificErrorType', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='configQueryErrorType', full_name='qm.grpc.jobManager.JobErrorDetails.configQueryErrorType', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='qm.grpc.jobManager.JobErrorDetails.message', index=2,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='errorType', full_name='qm.grpc.jobManager.JobErrorDetails.errorType',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=839,
  serialized_end=1016,
)


_JOBOPERATIONSPECIFICERROR = _descriptor.Descriptor(
  name='JobOperationSpecificError',
  full_name='qm.grpc.jobManager.JobOperationSpecificError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='qm.grpc.jobManager.JobOperationSpecificError.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message', full_name='qm.grpc.jobManager.JobOperationSpecificError.message', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1018,
  serialized_end=1109,
)


_DIGITALINPUTPORT = _descriptor.Descriptor(
  name='DigitalInputPort',
  full_name='qm.grpc.jobManager.DigitalInputPort',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='controllerName', full_name='qm.grpc.jobManager.DigitalInputPort.controllerName', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='portNumber', full_name='qm.grpc.jobManager.DigitalInputPort.portNumber', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1111,
  serialized_end=1173,
)


_GETDIGITALINPUTPOLARITYREQUEST = _descriptor.Descriptor(
  name='GetDigitalInputPolarityRequest',
  full_name='qm.grpc.jobManager.GetDigitalInputPolarityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.jobManager.GetDigitalInputPolarityRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalInputPort', full_name='qm.grpc.jobManager.GetDigitalInputPolarityRequest.digitalInputPort', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1175,
  serialized_end=1286,
)


_GETDIGITALINPUTPOLARITYRESPONSE = _descriptor.Descriptor(
  name='GetDigitalInputPolarityResponse',
  full_name='qm.grpc.jobManager.GetDigitalInputPolarityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobManagerResponseHeader', full_name='qm.grpc.jobManager.GetDigitalInputPolarityResponse.jobManagerResponseHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalInputPort', full_name='qm.grpc.jobManager.GetDigitalInputPolarityResponse.digitalInputPort', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polarity', full_name='qm.grpc.jobManager.GetDigitalInputPolarityResponse.polarity', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1289,
  serialized_end=1530,
)


_SETDIGITALINPUTPOLARITYREQUEST = _descriptor.Descriptor(
  name='SetDigitalInputPolarityRequest',
  full_name='qm.grpc.jobManager.SetDigitalInputPolarityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.jobManager.SetDigitalInputPolarityRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalInputPort', full_name='qm.grpc.jobManager.SetDigitalInputPolarityRequest.digitalInputPort', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polarity', full_name='qm.grpc.jobManager.SetDigitalInputPolarityRequest.polarity', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1533,
  serialized_end=1708,
)


_SETDIGITALINPUTPOLARITYRESPONSE = _descriptor.Descriptor(
  name='SetDigitalInputPolarityResponse',
  full_name='qm.grpc.jobManager.SetDigitalInputPolarityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobManagerResponseHeader', full_name='qm.grpc.jobManager.SetDigitalInputPolarityResponse.jobManagerResponseHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='polarity', full_name='qm.grpc.jobManager.SetDigitalInputPolarityResponse.polarity', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1711,
  serialized_end=1888,
)


_GETDIGITALINPUTWINDOWREQUEST = _descriptor.Descriptor(
  name='GetDigitalInputWindowRequest',
  full_name='qm.grpc.jobManager.GetDigitalInputWindowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.jobManager.GetDigitalInputWindowRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalInputPort', full_name='qm.grpc.jobManager.GetDigitalInputWindowRequest.digitalInputPort', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1890,
  serialized_end=1999,
)


_GETDIGITALINPUTWINDOWRESPONSE = _descriptor.Descriptor(
  name='GetDigitalInputWindowResponse',
  full_name='qm.grpc.jobManager.GetDigitalInputWindowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobManagerResponseHeader', full_name='qm.grpc.jobManager.GetDigitalInputWindowResponse.jobManagerResponseHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalInputPort', full_name='qm.grpc.jobManager.GetDigitalInputWindowResponse.digitalInputPort', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window', full_name='qm.grpc.jobManager.GetDigitalInputWindowResponse.window', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2002,
  serialized_end=2193,
)


_SETDIGITALINPUTWINDOWREQUEST = _descriptor.Descriptor(
  name='SetDigitalInputWindowRequest',
  full_name='qm.grpc.jobManager.SetDigitalInputWindowRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.jobManager.SetDigitalInputWindowRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalInputPort', full_name='qm.grpc.jobManager.SetDigitalInputWindowRequest.digitalInputPort', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window', full_name='qm.grpc.jobManager.SetDigitalInputWindowRequest.window', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2195,
  serialized_end=2320,
)


_SETDIGITALINPUTWINDOWRESPONSE = _descriptor.Descriptor(
  name='SetDigitalInputWindowResponse',
  full_name='qm.grpc.jobManager.SetDigitalInputWindowResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobManagerResponseHeader', full_name='qm.grpc.jobManager.SetDigitalInputWindowResponse.jobManagerResponseHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='window', full_name='qm.grpc.jobManager.SetDigitalInputWindowResponse.window', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2322,
  serialized_end=2449,
)


_GETDIGITALINPUTTHRESHOLDREQUEST = _descriptor.Descriptor(
  name='GetDigitalInputThresholdRequest',
  full_name='qm.grpc.jobManager.GetDigitalInputThresholdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.jobManager.GetDigitalInputThresholdRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalInputPort', full_name='qm.grpc.jobManager.GetDigitalInputThresholdRequest.digitalInputPort', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2451,
  serialized_end=2563,
)


_GETDIGITALINPUTTHRESHOLDRESPONSE = _descriptor.Descriptor(
  name='GetDigitalInputThresholdResponse',
  full_name='qm.grpc.jobManager.GetDigitalInputThresholdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobManagerResponseHeader', full_name='qm.grpc.jobManager.GetDigitalInputThresholdResponse.jobManagerResponseHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalInputPort', full_name='qm.grpc.jobManager.GetDigitalInputThresholdResponse.digitalInputPort', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='qm.grpc.jobManager.GetDigitalInputThresholdResponse.threshold', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2566,
  serialized_end=2763,
)


_SETDIGITALINPUTTHRESHOLDREQUEST = _descriptor.Descriptor(
  name='SetDigitalInputThresholdRequest',
  full_name='qm.grpc.jobManager.SetDigitalInputThresholdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobId', full_name='qm.grpc.jobManager.SetDigitalInputThresholdRequest.jobId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='digitalInputPort', full_name='qm.grpc.jobManager.SetDigitalInputThresholdRequest.digitalInputPort', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='qm.grpc.jobManager.SetDigitalInputThresholdRequest.threshold', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2766,
  serialized_end=2897,
)


_SETDIGITALINPUTTHRESHOLDRESPONSE = _descriptor.Descriptor(
  name='SetDigitalInputThresholdResponse',
  full_name='qm.grpc.jobManager.SetDigitalInputThresholdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='jobManagerResponseHeader', full_name='qm.grpc.jobManager.SetDigitalInputThresholdResponse.jobManagerResponseHeader', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='threshold', full_name='qm.grpc.jobManager.SetDigitalInputThresholdResponse.threshold', index=1,
      number=2, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2900,
  serialized_end=3033,
)

_GETELEMENTCORRECTIONREQUEST.fields_by_name['correction'].message_type = qm_dot_pb_dot_general__messages__pb2._MATRIX
_GETELEMENTCORRECTIONRESPONSE.fields_by_name['jobManagerResponseHeader'].message_type = _JOBMANAGERRESPONSEHEADER
_GETELEMENTCORRECTIONRESPONSE.fields_by_name['correction'].message_type = qm_dot_pb_dot_general__messages__pb2._MATRIX
_SETELEMENTCORRECTIONREQUEST.fields_by_name['correction'].message_type = qm_dot_pb_dot_general__messages__pb2._MATRIX
_SETELEMENTCORRECTIONRESPONSE.fields_by_name['jobManagerResponseHeader'].message_type = _JOBMANAGERRESPONSEHEADER
_SETELEMENTCORRECTIONRESPONSE.fields_by_name['correction'].message_type = qm_dot_pb_dot_general__messages__pb2._MATRIX
_JOBMANAGERRESPONSEHEADER.fields_by_name['jobManagerErrorType'].enum_type = qm_dot_pb_dot_errors__pb2._JOBMANAGERERRORTYPES
_JOBMANAGERRESPONSEHEADER.fields_by_name['jobErrorDetails'].message_type = _JOBERRORDETAILS
_JOBERRORDETAILS.fields_by_name['jobOperationSpecificErrorType'].enum_type = qm_dot_pb_dot_errors__pb2._JOBOPERATIONSPECIFICERRORTYPES
_JOBERRORDETAILS.fields_by_name['configQueryErrorType'].enum_type = qm_dot_pb_dot_errors__pb2._CONFIGQUERYERRORTYPES
_JOBERRORDETAILS.oneofs_by_name['errorType'].fields.append(
  _JOBERRORDETAILS.fields_by_name['jobOperationSpecificErrorType'])
_JOBERRORDETAILS.fields_by_name['jobOperationSpecificErrorType'].containing_oneof = _JOBERRORDETAILS.oneofs_by_name['errorType']
_JOBERRORDETAILS.oneofs_by_name['errorType'].fields.append(
  _JOBERRORDETAILS.fields_by_name['configQueryErrorType'])
_JOBERRORDETAILS.fields_by_name['configQueryErrorType'].containing_oneof = _JOBERRORDETAILS.oneofs_by_name['errorType']
_JOBOPERATIONSPECIFICERROR.fields_by_name['type'].enum_type = qm_dot_pb_dot_errors__pb2._JOBOPERATIONSPECIFICERRORTYPES
_GETDIGITALINPUTPOLARITYREQUEST.fields_by_name['digitalInputPort'].message_type = _DIGITALINPUTPORT
_GETDIGITALINPUTPOLARITYRESPONSE.fields_by_name['jobManagerResponseHeader'].message_type = _JOBMANAGERRESPONSEHEADER
_GETDIGITALINPUTPOLARITYRESPONSE.fields_by_name['digitalInputPort'].message_type = _DIGITALINPUTPORT
_GETDIGITALINPUTPOLARITYRESPONSE.fields_by_name['polarity'].enum_type = _DIGITALINPUTPORTPOLARITY
_SETDIGITALINPUTPOLARITYREQUEST.fields_by_name['digitalInputPort'].message_type = _DIGITALINPUTPORT
_SETDIGITALINPUTPOLARITYREQUEST.fields_by_name['polarity'].enum_type = _DIGITALINPUTPORTPOLARITY
_SETDIGITALINPUTPOLARITYRESPONSE.fields_by_name['jobManagerResponseHeader'].message_type = _JOBMANAGERRESPONSEHEADER
_SETDIGITALINPUTPOLARITYRESPONSE.fields_by_name['polarity'].enum_type = _DIGITALINPUTPORTPOLARITY
_GETDIGITALINPUTWINDOWREQUEST.fields_by_name['digitalInputPort'].message_type = _DIGITALINPUTPORT
_GETDIGITALINPUTWINDOWRESPONSE.fields_by_name['jobManagerResponseHeader'].message_type = _JOBMANAGERRESPONSEHEADER
_GETDIGITALINPUTWINDOWRESPONSE.fields_by_name['digitalInputPort'].message_type = _DIGITALINPUTPORT
_SETDIGITALINPUTWINDOWREQUEST.fields_by_name['digitalInputPort'].message_type = _DIGITALINPUTPORT
_SETDIGITALINPUTWINDOWRESPONSE.fields_by_name['jobManagerResponseHeader'].message_type = _JOBMANAGERRESPONSEHEADER
_GETDIGITALINPUTTHRESHOLDREQUEST.fields_by_name['digitalInputPort'].message_type = _DIGITALINPUTPORT
_GETDIGITALINPUTTHRESHOLDRESPONSE.fields_by_name['jobManagerResponseHeader'].message_type = _JOBMANAGERRESPONSEHEADER
_GETDIGITALINPUTTHRESHOLDRESPONSE.fields_by_name['digitalInputPort'].message_type = _DIGITALINPUTPORT
_SETDIGITALINPUTTHRESHOLDREQUEST.fields_by_name['digitalInputPort'].message_type = _DIGITALINPUTPORT
_SETDIGITALINPUTTHRESHOLDRESPONSE.fields_by_name['jobManagerResponseHeader'].message_type = _JOBMANAGERRESPONSEHEADER
DESCRIPTOR.message_types_by_name['GetElementCorrectionRequest'] = _GETELEMENTCORRECTIONREQUEST
DESCRIPTOR.message_types_by_name['GetElementCorrectionResponse'] = _GETELEMENTCORRECTIONRESPONSE
DESCRIPTOR.message_types_by_name['SetElementCorrectionRequest'] = _SETELEMENTCORRECTIONREQUEST
DESCRIPTOR.message_types_by_name['SetElementCorrectionResponse'] = _SETELEMENTCORRECTIONRESPONSE
DESCRIPTOR.message_types_by_name['JobManagerResponseHeader'] = _JOBMANAGERRESPONSEHEADER
DESCRIPTOR.message_types_by_name['JobErrorDetails'] = _JOBERRORDETAILS
DESCRIPTOR.message_types_by_name['JobOperationSpecificError'] = _JOBOPERATIONSPECIFICERROR
DESCRIPTOR.message_types_by_name['DigitalInputPort'] = _DIGITALINPUTPORT
DESCRIPTOR.message_types_by_name['GetDigitalInputPolarityRequest'] = _GETDIGITALINPUTPOLARITYREQUEST
DESCRIPTOR.message_types_by_name['GetDigitalInputPolarityResponse'] = _GETDIGITALINPUTPOLARITYRESPONSE
DESCRIPTOR.message_types_by_name['SetDigitalInputPolarityRequest'] = _SETDIGITALINPUTPOLARITYREQUEST
DESCRIPTOR.message_types_by_name['SetDigitalInputPolarityResponse'] = _SETDIGITALINPUTPOLARITYRESPONSE
DESCRIPTOR.message_types_by_name['GetDigitalInputWindowRequest'] = _GETDIGITALINPUTWINDOWREQUEST
DESCRIPTOR.message_types_by_name['GetDigitalInputWindowResponse'] = _GETDIGITALINPUTWINDOWRESPONSE
DESCRIPTOR.message_types_by_name['SetDigitalInputWindowRequest'] = _SETDIGITALINPUTWINDOWREQUEST
DESCRIPTOR.message_types_by_name['SetDigitalInputWindowResponse'] = _SETDIGITALINPUTWINDOWRESPONSE
DESCRIPTOR.message_types_by_name['GetDigitalInputThresholdRequest'] = _GETDIGITALINPUTTHRESHOLDREQUEST
DESCRIPTOR.message_types_by_name['GetDigitalInputThresholdResponse'] = _GETDIGITALINPUTTHRESHOLDRESPONSE
DESCRIPTOR.message_types_by_name['SetDigitalInputThresholdRequest'] = _SETDIGITALINPUTTHRESHOLDREQUEST
DESCRIPTOR.message_types_by_name['SetDigitalInputThresholdResponse'] = _SETDIGITALINPUTTHRESHOLDRESPONSE
DESCRIPTOR.enum_types_by_name['DigitalInputPortPolarity'] = _DIGITALINPUTPORTPOLARITY
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetElementCorrectionRequest = _reflection.GeneratedProtocolMessageType('GetElementCorrectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETELEMENTCORRECTIONREQUEST,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.GetElementCorrectionRequest)
  })
_sym_db.RegisterMessage(GetElementCorrectionRequest)

GetElementCorrectionResponse = _reflection.GeneratedProtocolMessageType('GetElementCorrectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETELEMENTCORRECTIONRESPONSE,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.GetElementCorrectionResponse)
  })
_sym_db.RegisterMessage(GetElementCorrectionResponse)

SetElementCorrectionRequest = _reflection.GeneratedProtocolMessageType('SetElementCorrectionRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETELEMENTCORRECTIONREQUEST,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.SetElementCorrectionRequest)
  })
_sym_db.RegisterMessage(SetElementCorrectionRequest)

SetElementCorrectionResponse = _reflection.GeneratedProtocolMessageType('SetElementCorrectionResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETELEMENTCORRECTIONRESPONSE,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.SetElementCorrectionResponse)
  })
_sym_db.RegisterMessage(SetElementCorrectionResponse)

JobManagerResponseHeader = _reflection.GeneratedProtocolMessageType('JobManagerResponseHeader', (_message.Message,), {
  'DESCRIPTOR' : _JOBMANAGERRESPONSEHEADER,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.JobManagerResponseHeader)
  })
_sym_db.RegisterMessage(JobManagerResponseHeader)

JobErrorDetails = _reflection.GeneratedProtocolMessageType('JobErrorDetails', (_message.Message,), {
  'DESCRIPTOR' : _JOBERRORDETAILS,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.JobErrorDetails)
  })
_sym_db.RegisterMessage(JobErrorDetails)

JobOperationSpecificError = _reflection.GeneratedProtocolMessageType('JobOperationSpecificError', (_message.Message,), {
  'DESCRIPTOR' : _JOBOPERATIONSPECIFICERROR,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.JobOperationSpecificError)
  })
_sym_db.RegisterMessage(JobOperationSpecificError)

DigitalInputPort = _reflection.GeneratedProtocolMessageType('DigitalInputPort', (_message.Message,), {
  'DESCRIPTOR' : _DIGITALINPUTPORT,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.DigitalInputPort)
  })
_sym_db.RegisterMessage(DigitalInputPort)

GetDigitalInputPolarityRequest = _reflection.GeneratedProtocolMessageType('GetDigitalInputPolarityRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDIGITALINPUTPOLARITYREQUEST,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.GetDigitalInputPolarityRequest)
  })
_sym_db.RegisterMessage(GetDigitalInputPolarityRequest)

GetDigitalInputPolarityResponse = _reflection.GeneratedProtocolMessageType('GetDigitalInputPolarityResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDIGITALINPUTPOLARITYRESPONSE,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.GetDigitalInputPolarityResponse)
  })
_sym_db.RegisterMessage(GetDigitalInputPolarityResponse)

SetDigitalInputPolarityRequest = _reflection.GeneratedProtocolMessageType('SetDigitalInputPolarityRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDIGITALINPUTPOLARITYREQUEST,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.SetDigitalInputPolarityRequest)
  })
_sym_db.RegisterMessage(SetDigitalInputPolarityRequest)

SetDigitalInputPolarityResponse = _reflection.GeneratedProtocolMessageType('SetDigitalInputPolarityResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETDIGITALINPUTPOLARITYRESPONSE,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.SetDigitalInputPolarityResponse)
  })
_sym_db.RegisterMessage(SetDigitalInputPolarityResponse)

GetDigitalInputWindowRequest = _reflection.GeneratedProtocolMessageType('GetDigitalInputWindowRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDIGITALINPUTWINDOWREQUEST,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.GetDigitalInputWindowRequest)
  })
_sym_db.RegisterMessage(GetDigitalInputWindowRequest)

GetDigitalInputWindowResponse = _reflection.GeneratedProtocolMessageType('GetDigitalInputWindowResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDIGITALINPUTWINDOWRESPONSE,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.GetDigitalInputWindowResponse)
  })
_sym_db.RegisterMessage(GetDigitalInputWindowResponse)

SetDigitalInputWindowRequest = _reflection.GeneratedProtocolMessageType('SetDigitalInputWindowRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDIGITALINPUTWINDOWREQUEST,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.SetDigitalInputWindowRequest)
  })
_sym_db.RegisterMessage(SetDigitalInputWindowRequest)

SetDigitalInputWindowResponse = _reflection.GeneratedProtocolMessageType('SetDigitalInputWindowResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETDIGITALINPUTWINDOWRESPONSE,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.SetDigitalInputWindowResponse)
  })
_sym_db.RegisterMessage(SetDigitalInputWindowResponse)

GetDigitalInputThresholdRequest = _reflection.GeneratedProtocolMessageType('GetDigitalInputThresholdRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETDIGITALINPUTTHRESHOLDREQUEST,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.GetDigitalInputThresholdRequest)
  })
_sym_db.RegisterMessage(GetDigitalInputThresholdRequest)

GetDigitalInputThresholdResponse = _reflection.GeneratedProtocolMessageType('GetDigitalInputThresholdResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETDIGITALINPUTTHRESHOLDRESPONSE,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.GetDigitalInputThresholdResponse)
  })
_sym_db.RegisterMessage(GetDigitalInputThresholdResponse)

SetDigitalInputThresholdRequest = _reflection.GeneratedProtocolMessageType('SetDigitalInputThresholdRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDIGITALINPUTTHRESHOLDREQUEST,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.SetDigitalInputThresholdRequest)
  })
_sym_db.RegisterMessage(SetDigitalInputThresholdRequest)

SetDigitalInputThresholdResponse = _reflection.GeneratedProtocolMessageType('SetDigitalInputThresholdResponse', (_message.Message,), {
  'DESCRIPTOR' : _SETDIGITALINPUTTHRESHOLDRESPONSE,
  '__module__' : 'qm.pb.job_manager_pb2'
  # @@protoc_insertion_point(class_scope:qm.grpc.jobManager.SetDigitalInputThresholdResponse)
  })
_sym_db.RegisterMessage(SetDigitalInputThresholdResponse)


DESCRIPTOR._options = None

_JOBMANAGERSERVICE = _descriptor.ServiceDescriptor(
  name='JobManagerService',
  full_name='qm.grpc.jobManager.JobManagerService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  create_key=_descriptor._internal_create_key,
  serialized_start=3097,
  serialized_end=4168,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetElementCorrection',
    full_name='qm.grpc.jobManager.JobManagerService.GetElementCorrection',
    index=0,
    containing_service=None,
    input_type=_GETELEMENTCORRECTIONREQUEST,
    output_type=_GETELEMENTCORRECTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetElementCorrection',
    full_name='qm.grpc.jobManager.JobManagerService.SetElementCorrection',
    index=1,
    containing_service=None,
    input_type=_SETELEMENTCORRECTIONREQUEST,
    output_type=_SETELEMENTCORRECTIONRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDigitalInputPolarity',
    full_name='qm.grpc.jobManager.JobManagerService.GetDigitalInputPolarity',
    index=2,
    containing_service=None,
    input_type=_GETDIGITALINPUTPOLARITYREQUEST,
    output_type=_GETDIGITALINPUTPOLARITYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDigitalInputPolarity',
    full_name='qm.grpc.jobManager.JobManagerService.SetDigitalInputPolarity',
    index=3,
    containing_service=None,
    input_type=_SETDIGITALINPUTPOLARITYREQUEST,
    output_type=_SETDIGITALINPUTPOLARITYRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDigitalInputWindow',
    full_name='qm.grpc.jobManager.JobManagerService.GetDigitalInputWindow',
    index=4,
    containing_service=None,
    input_type=_GETDIGITALINPUTWINDOWREQUEST,
    output_type=_GETDIGITALINPUTWINDOWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDigitalInputWindow',
    full_name='qm.grpc.jobManager.JobManagerService.SetDigitalInputWindow',
    index=5,
    containing_service=None,
    input_type=_SETDIGITALINPUTWINDOWREQUEST,
    output_type=_SETDIGITALINPUTWINDOWRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='GetDigitalInputThreshold',
    full_name='qm.grpc.jobManager.JobManagerService.GetDigitalInputThreshold',
    index=6,
    containing_service=None,
    input_type=_GETDIGITALINPUTTHRESHOLDREQUEST,
    output_type=_GETDIGITALINPUTTHRESHOLDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
  _descriptor.MethodDescriptor(
    name='SetDigitalInputThreshold',
    full_name='qm.grpc.jobManager.JobManagerService.SetDigitalInputThreshold',
    index=7,
    containing_service=None,
    input_type=_SETDIGITALINPUTTHRESHOLDREQUEST,
    output_type=_SETDIGITALINPUTTHRESHOLDRESPONSE,
    serialized_options=None,
    create_key=_descriptor._internal_create_key,
  ),
])
_sym_db.RegisterServiceDescriptor(_JOBMANAGERSERVICE)

DESCRIPTOR.services_by_name['JobManagerService'] = _JOBMANAGERSERVICE

# @@protoc_insertion_point(module_scope)
